# Donations
It takes me a long time to make these libraries. If you would like to support my work, Then you can follow my patreon :)

https://www.patreon.com/Schkimansky

# Library
This is a easy to use python library that allows you to port c++ libraries to python

```python
import vialin

# example coming soon
```

# Installation
```bash
pip install vialin
```

# Documentation
Coming soon.
